/* ATtiny13A 9.6MHz */

#define F_CPU 1200000L // !!! i have made a terrible mistake here that makes all delays 8 times shorter 
                       // (timer and should be good, ADC frequency is too high); 9600000L is worth trying !!!

#include <avr/io.h>
#include <util/delay.h>  


int main(void) {

  uint8_t i, j, period, pwm;

  /* Set up prescaling of Internal RC Oscillator running to 1 (9.6 MHz) */
  CLKPR = (1<<CLKPCE);
  CLKPR = (0<<CLKPS3) | (0<<CLKPS2) | (0<<CLKPS1) | (0<<CLKPS0);

  _delay_ms(10); // wait for stabilization after clock frequency change

  /* Set up I/O Ports */
  DDRB |= (1 << PB1) | (1 << PB0); // PB1 and PB0 as outputs
  PORTB |= (1 << PB2); // PB2 as input with pull-up enabled

  /* Set up Timer/Counter0 */
  TCCR0A |= (1 << WGM01); // set to 'CTC' mode
  TCCR0A |= (1 << COM0A0); // OC0A - toggle
  TCCR0B |= (1 << CS00); // 8-bit timer/counter prescaler to 1

  /* Set up ADC */
  ADMUX |= (1 << MUX1); //temporarily set input channel to ADC2 (PB4);
  ADMUX |= (1 << ADLAR);  //left adjust result
  ADCSRA |= (1 << ADPS2) | (1 << ADEN);  // prescaler to 16 (should be 75kHz if not for bad F_CPU), enable ADC

  _delay_ms(40); // wait for additional stabilization after peripherals setup (most likely not necessary)

  while(1) {

    ADMUX &= ~(1 << MUX0); //set input channel to ADC2 (PB4);
    ADCSRA |= (1 << ADSC); // start analog-to-digital conversion
    while (ADCSRA & (1 << ADSC)); // wait for it to finish
    period = ADCH; // copy 8 most significant bits of ADC read-out

    OCR0A = period; // update Timer/Counter0 with new period/frequency

    ADMUX |= (1 << MUX0); //set input channel to ADC3 (PB3);
    ADCSRA |= (1 << ADSC);  // start analog-to-digital conversion
    while (ADCSRA & (1 << ADSC));  // wait for it to finish
    pwm = ADCH; // copy 8 most significant bits of ADC read-out

    for(i = 0; i < 20; i++) {  // 20 executions of the code inside this loop should take approximately 203 ms, so analog 
                               // inputs will be read 5 times each second

      for(j = 0; j < 254; j++) { // execute a loop that contains 40 μs delay 254 times, which gives 10.16 ms in total(98,43 Hz)

        if( (j<pwm) && !(PINB & (1 << PB2)) ) PORTB |= (1 << PB1); // enable switching of H-bridge for small amount of 40 μs 
            // delays when 'pwm' variable is small, and for large amount when 'pwm' is high; switching of H-bridge is only 
            // possible when button connected to the PB2 pin is pressed
        else PORTB &= ~(1 << PB1); // disable switching of H-bridge for remaining time or when button is not pushed
        _delay_us(40); // after state of PB1 output has been decided, wait for 40 μs

      }

    }

  }


}
